//	gmap.js (+ gmap.html + gmap/search.gif) for Google Maps API v3
//	Copyright 2010 CMONOS Co.Ltd.
//	Version: 2.0.2
//	License: MIT License 
//	※ Google Maps API および各種マーカー画像に関する全ての権利は米 Google, Inc が保有しています。
//
//	URI: http://cmonos.jp/
//	Last Modified: 2011-03-22
//	Author: CMONOS Co.Ltd.
//
//	【ストリートビュー関連コードのベースとしたデモ】
//	Street View Data Querying (Example by Tom Manshreck)
//	http://gmaps-samples.googlecode.com/svn/trunk/streetview/streetview_layer.html
//
//	【使い方】
//	次のような <iframe> タグで、地図を埋め込みます。
//
//	<iframe class="gmap-frame" id="gmap-canvas" src="./gmap.html?key=API_KEY&om=1&z=4&c=36.315125,137.504883"  width="500" height="400" scrolling="no" marginwidth="0" marginheight="0" frameborder="0">
//	<a href="./gmap.html?key=API_KEY&om=1&z=4&c=36.315125,137.504883" target="_blank">新しいウィンドウで地図を開く</a>
//	</iframe>
//
//	【地図呼び出しオプション】
//	key		GoogleMaps API キー(http://code.google.com/apis/maps/signup.html で取得します)
//	om		1=概観地図(右下に表示される小さな四角い概観地図)を表示する場合
//	z		拡大倍率(0-17)
//	t		地図のタイプ(k=衛星写真/h=地図と衛星の合成/p=地形/設定なし=通常の地図)
//	c		中心座標の緯度,中心座標の経度
//	m		中心座標コメント
//	mw		中心座標コメントを表示する情報ウィンドウの幅
//	mk		カスタムマーカー画像URL
//	mks		カスタムマーカー影画像URL
//	mka		カスタムマーカーが地図に固定される水平位置（画像に対して left center right で指定します）
//	mkv		カスタムマーカーが地図に固定される垂直位置（画像に対して top center bottom で指定します）
//	s		1=地図検索欄を表示する
//	sv		1=ストリートビューを表示する
//	url		kml ファイルの URL
//	fit		1=kml ファイルに合わせて中心座標と拡大倍率を調整する
//	d		kml ファイルに記述された線分の距離を表示するかどうか
//			(1=始点から終点までの総延長を表示する/2=総延長に加えて始点と終点の直線距離を表示する)
//	width	地図の幅(ピクセル)
//	height	地図の高さ(ピクセル)
//	tr		情報ウィンドウ内リンクのターゲット p=_parent/s=_self/b=_blank/t=_top
//	i		1=index 用KMLを表示する(リンクつきのPlacemarkerのみで構成されたKML)
//	ns		1=index 用KMLを表示する際、マーカーを親HTMLのリンクと連動させない
//	opn		地図を埋め込んだ記事の URL/URLが一致したマーカーの情報ウィンドウを開きます
//	r		1=地図を移動または拡大縮小する度に kml を再読み込みする(必ず fit を無効化します)
//	sf		kml 再検索フォームのID
//	lb		表示している Placemarker の一覧を表示するリスト(<ul> or <ol>)を含むブロック(リストが空の時非表示にします)
//	li		表示している Placemarker の一覧を表示するリスト(<ul> or <ol>)
//
//	【以下は呼びだし元ページのフォームに地図の情報を書き込む場合に使用するオプションです】
//	z_field		表示中の地図の拡大倍率を収める入力欄のID
//	t_field		表示中の地図の地図のタイプを収める入力欄のID
//	c_field		表示中の地図の中心座標を収める入力欄のID
//	m_field		表示中の地図の中心座標コメントが収められている入力欄のID
//	mk_field	カスタムマーカー画像URLが収められている入力欄のID
//	mk_disabled	カスタムマーカー画像URLが収められている入力欄を有効化するチェックボックスのID(オプション)
//	fit_field	表示中の地図を KML ファイルにあわせて調整するかどうかの設定が収められているチェックボックスのID
//	addr_field	地図検索欄に読み込む住所が収められている住所入力欄のIDのカンマ区切りリスト(都道府県,市区群,番地,ビル)

//	外部ドメインからのアクセスを許可する場合は下記を false にします。
var domain_check = true;

//	デフォルトのマーカーアイコン
var icon_cache = new Array();
readImage("http://labs.google.com/ridefinder/images/mm_20_red.png");
readImage("http://labs.google.com/ridefinder/images/mm_20_shadow.png");
function  getMarkerImage() {
	minimarker_disabled = false;
	return getMarkerImageFrom(
		"http://labs.google.com/ridefinder/images/mm_20_red.png",
		12,
		20,
		6,
		20,
		"http://labs.google.com/ridefinder/images/mm_20_shadow.png",
		22,
		20
	);
}

//	定規アイコン
function getMeasureImage() {
	return getMarkerImageFrom(
		"http://maps.gstatic.com/mapfiles/kml/pal5/icon5.png",
		32,
		32,
		16,
		32,
		"http://maps.gstatic.com/mapfiles/kml/pal5/icon5s.png",
		59,
		32
	);
}

//	選択マーカー画像
readImage("http://labs.google.com/ridefinder/images/mm_20_orange.png");
function toggleMarkerImage(this_marker,is_selected) {
	this_marker.setIcon(((is_selected) ? "http://labs.google.com/ridefinder/images/mm_20_orange.png" : "http://labs.google.com/ridefinder/images/mm_20_red.png"));
}

var q = urlDecode(self.document.location.search);
var api_enabled = false;
var map;
var map_center;
var center_marker = null;
var geocoder_client = null;
var measure_icon = null;
var kml_refreshing = false;
var default_icon = null;
var streetview_window = null;
var streetview_window_is_opened = null;
var streetview_holder = null;
var streetview_node = null;
var streetview_canvas = null;
var streetview_panorama = null;
var streetview_last_position = null;
var kml_overlay = null;
var kml_objects = null;
var _caller = (parent && parent != self) ? parent : (opener) ? opener : self;
if (!domain_check || _caller.document.domain == self.document.domain) api_enabled = true;
if ((navigator.userAgent.match(/MSIE\s*(\d+\.\d+)/) && parseFloat(RegExp.$1) < 5.5) || (navigator.userAgent.match(/Safari\/(\d+)/) && parseFloat(RegExp.$1) < 400)) api_enabled = false;
if (api_enabled) self.document.write('<script type="text/javascript" src="http://maps.google.com/maps/api/js?sensor=' + ((q["sensor"]) ? 'true' : 'false') + '&amp;language=ja' + ((q["key"] != null && q["key"] != "") ? '&amp;key=' + q["key"] : '') + '"></script>');
var z_field = null;
var t_field = null;
var c_field = null;
var m_field = null;
var mk_field = null;
var mkc_field = null;
var mka_field = null;
var mkv_field = null;
var fit_field = null;
var addr_field_ids = null;
var mw = (q["mw"] != null && q["mw"] > 100) ? q["mw"] : 280;
if (q["z_field"] != null && q["z_field"] != "" && _caller.document.getElementById(q["z_field"])) z_field = _caller.document.getElementById(q["z_field"]);
if (q["t_field"] != null && q["t_field"] != "" && _caller.document.getElementById(q["t_field"])) t_field = _caller.document.getElementById(q["t_field"]);
if (q["c_field"] != null && q["c_field"] != "" && _caller.document.getElementById(q["c_field"])) c_field = _caller.document.getElementById(q["c_field"]);
if (q["m_field"] != null && q["m_field"] != "" && _caller.document.getElementById(q["m_field"])) m_field = _caller.document.getElementById(q["m_field"]);
if (q["mk_field"] != null && q["mk_field"] != "" && _caller.document.getElementById(q["mk_field"])) mk_field = _caller.document.getElementById(q["mk_field"]);
if (q["mkc_field"] != null && q["mkc_field"] != "" && _caller.document.getElementById(q["mkc_field"])) mkc_field = _caller.document.getElementById(q["mkc_field"]);
if (q["mka_field"] != null && q["mka_field"] != "" && _caller.document.getElementById(q["mka_field"])) mka_field = _caller.document.getElementById(q["mka_field"]);
if (q["mkv_field"] != null && q["mkv_field"] != "" && _caller.document.getElementById(q["mkv_field"])) mkv_field = _caller.document.getElementById(q["mkv_field"]);
if (q["fit_field"] != null && q["fit_field"] != "" && _caller.document.getElementById(q["fit_field"])) fit_field = _caller.document.getElementById(q["fit_field"]);
if (q["addr_field"] != null && q["addr_field"] != "") addr_field_ids = q["addr_field"].split(/,/);
var field_enabled = (z_field != null || t_field != null || c_field != null || m_field != null || fit_field != null) ? true : false;
var kml_url = null;
var base_url = null;
var search_form = null;
var list_box = null;
var list = null;
var minimarker_disabled = false;
var kml_by_myself = (q["i"] != null && parseInt(q["i"]) > 0) ? true : false;
var nosync = (q["ns"] != null && parseInt(q["ns"]) > 0) ? true : false;
if (q["lb"] != null && q["lb"] != "" && _caller.document.getElementById(q["lb"])) list_box = _caller.document.getElementById(q["lb"]);
if (q["li"] != null && q["li"] != "" && _caller.document.getElementById(q["li"])) list = _caller.document.getElementById(q["li"]);
if (q["r"] != null && q["r"] == 1) q["fit"] = null;
if (q["mk"] != null) readImage(q["mk"]);
if (q["mks"] != null) readImage(q["mks"]);
if (mk_field != null) {
	if (mk_field.type.search(/select/) != -1) {
		for (var i=0; i < mk_field.options.length; i++) {
			if (mk_field.options[i].value != null && mk_field.options[i].value != "") {
				readImage(mk_field.options[i].value);
			}
		}
	} else if (mk_field.value != null && mk_field.value != "") {
		readImage(mk_field.value);
	}
};
var dw = (!q["dw"] || isNaN(q["dw"])) ? 640 : parseInt(q["dw"]);
var dh = (!q["dh"] || isNaN(q["dh"])) ? 480 : parseInt(q["dh"]);
function readImage(this_url) {
	var i = icon_cache.length;
	icon_cache[i] = new Image();
	icon_cache[i].src = this_url;
}
function initialize() {
	var w;
	var h;
	var full_window = false;
	if (q["width"] != null && q["width"] != "" && !isNaN(q["width"]) && q["height"] != null && q["height"] != "" && !isNaN(q["height"])) {
		w = parseInt(q["width"]);
		h = parseInt(q["height"]);
	} else {
		full_window = true;
		w = ((self.innerWidth) ? self.innerWidth : ((document.compatMode != null && document.compatMode != "BackCompat") ? self.document.documentElement.clientWidth : self.document.body.clientWidth));
		h = ((self.innerHeight) ? self.innerHeight : ((document.compatMode != null && document.compatMode != "BackCompat") ? self.document.documentElement.clientHeight : self.document.body.clientHeight))
	}
	if (api_enabled) {
		var z = 4;
		var center = new Array(36.315125,137.504883);
		var map_canvas = self.document.getElementById("map");
		if (!full_window) {
			map_canvas.style.width = w + 'px';
			map_canvas.style.height = h + 'px';
		}
		if (q["c"] != null && q["c"] != "") center = q["c"].split(/,/);
		if (q["z"] != null && q["z"] != "" && !isNaN(q["z"])) z = parseInt(q["z"]);
		map_center = new google.maps.LatLng(center[0],center[1]);
		map = new google.maps.Map(map_canvas,{
			zoom		: z,
			center		: map_center,
			mapTypeId	: ((q["t"] == null || q["t"] == "") ? google.maps.MapTypeId.ROADMAP : (q["t"] == "k") ? google.maps.MapTypeId.SATELLITE : (q["t"] == "h") ? google.maps.MapTypeId.HYBRID : (q["t"] == "p") ? google.maps.MapTypeId.TERRAIN : google.maps.MapTypeId.ROADMAP),
			streetViewControl	: ((q["sv"] != null && q["sv"] == 1) ? true : false)
		});

		if (q["sv"] != null && q["sv"] == 1) {
			streetview_node = document.createElement('div');
			streetview_canvas = document.createElement('div');

			streetview_holder = document.createElement('div');
			streetview_holder.style.width = w + 'px';
			streetview_holder.style.height = h + 'px';
			streetview_holder.style.position = 'absolute';
			streetview_holder.style.overflow = 'hidden';
			streetview_holder.style.top = '-' + w + 'px';
			streetview_holder.style.left = '-' + h + 'px';
			streetview_holder.appendChild(streetview_canvas);
			self.document.body.appendChild(streetview_holder);

			streetview_panorama = new google.maps.StreetViewPanorama(streetview_canvas,{
				visible		: false
			});

			streetview_window = new google.maps.InfoWindow({ content : streetview_node, pixelOffset : new google.maps.Size(0, -33) });
			setStreetViewCanvasSize(w,h);

			if (full_window) {
				google.maps.event.addDomListener(
					self,
					'resize',
					function() {
						w = ((self.innerWidth) ? self.innerWidth : ((document.compatMode != null && document.compatMode != "BackCompat") ? self.document.documentElement.clientWidth : self.document.body.clientWidth));
						h = ((self.innerHeight) ? self.innerHeight : ((document.compatMode != null && document.compatMode != "BackCompat") ? self.document.documentElement.clientHeight : self.document.body.clientHeight))
						setStreetViewCanvasSize(w,h);
					}
				);
			}
			google.maps.event.addListener(
				streetview_window,
				'domready',
				function() {
					streetview_node.appendChild(streetview_canvas);
				}
			);
			google.maps.event.addListener(
				streetview_window,
				'closeclick',
				function() {
					if (streetview_window_is_opened) {
						streetview_holder.appendChild(streetview_canvas);
						streetview_panorama.setVisible(false);
						streetview_window_is_opened = false;
						streetview_last_position = null;
					}
				}
			);
			google.maps.event.addListener(
				streetview_panorama,
				'visible_changed',
				function() {
					if (streetview_panorama.getVisible()) {
						if (!streetview_window_is_opened) {
							streetview_window.setPosition(streetview_panorama.getPosition());
							streetview_window.open(map);
							streetview_window_is_opened = true;
						}
					} else if (streetview_window_is_opened) {
						streetview_holder.appendChild(streetview_canvas);
						streetview_window.close();
						streetview_window_is_opened = false;
						streetview_last_position = null;
					}
				}
			);
			google.maps.event.addListener(
				streetview_panorama,
				'position_changed',
				function() {
					var current_position = streetview_panorama.getPosition();
					streetview_window.setPosition(current_position);
					if (streetview_last_position != null && !current_position.equals(streetview_last_position)) {
						map_center = map.getCenter();
						var map_bounds = map.getBounds()
						if (map_bounds.contains(streetview_last_position)) {
							if (
									((Math.abs(streetview_last_position.lat()-current_position.lat()) < 0.0004) && (Math.abs(streetview_last_position.lng()-current_position.lng()) < 0.0004))
									|| (streetview_last_position.temp && (Math.abs(streetview_last_position.temp.lat()-current_position.lat()) < 0.0002) && (Math.abs(streetview_last_position.temp.lng()-current_position.lng()) < 0.0002))
								) {
								map.panTo(new google.maps.LatLng((map_center.lat() + current_position.lat() - streetview_last_position.lat()),(map_center.lng() + current_position.lng() - streetview_last_position.lng())));
							} else {
								streetview_last_position.temp = current_position;
								return;
							}
						} else {
							s = map_bounds.getSouthWest().lat();
							current_position = new google.maps.LatLng((((map_bounds.getNorthEast().lat() - s) / 10) + s),map_center.lng());
						}
					}
					streetview_last_position = current_position;
				}
			);
		}

		//if (q["om"] != null && q["om"] == 1) map.addControl(new GOverviewMapControl()); //there is no OverviewMapControl in the v3 API yet. 
		if ((m_field != null) || (q["m"] != null && q["m"] != "")) {
			if (m_field != null) {
				makeCenterMarker(true);
				if (mk_field != null) mk_field.onchange = function () { makeCenterMarker(true); };
				if (mkc_field != null) mkc_field.onclick = function () { makeCenterMarker(true); };
				if (mka_field != null) mka_field.onchange = function () { makeCenterMarker(true); };
				if (mkv_field != null) mkv_field.onchange = function () { makeCenterMarker(true); };
			} else {
				var center_marker_image = (q["mk"] != null && q["mk"] != "") ? getCustomMarkerImage(q["mk"],q["mka"],q["mkv"],q["mks"]) :  getMarkerImage();
				center_marker = new google.maps.Marker({
					position	: map_center,
					map			: map,
					icon		: center_marker_image.icon,
					shadow		: center_marker_image.shadow,
					flat		: ((center_marker_image.shadow == null) ? true : false)
				});
				google.maps.event.addListener(
					center_marker,
					"click",
					function () {
						if (!center_marker.info_window) center_marker.info_window = new google.maps.InfoWindow({
							content: '<div style="font-size: 14px">' + q["m"] + '</div>',
							maxWidth: mw
						});
						center_marker.info_window.open(map,center_marker);
					}
				);
			}
		}
		if (q["url"] != null && q["url"] != "") {
			kml_url = q["url"];
			base_url = q["url"].replace(/\?.*$/,'');
		} else if (q["sf"] != null && q["sf"] != "" && _caller.document.getElementById(q["sf"])) {
			search_form = _caller.document.getElementById(q["sf"]);
			base_url = search_form.action;
			kml_url = base_url + '?' + urlEncode(getHashFromForm(search_form));
		}
		if (kml_url != null) {
			google.maps.event.addListenerOnce( map, "tilesloaded", function () { refreshKml(); } );
			if (search_form != null) {
				search_form.onsubmit = function () {
					kml_url = base_url + '?' + urlEncode(getHashFromForm(this));
					refreshKml();
					return false;
				};
			}
			if (q["r"] != null && q["r"] == 1) {
				google.maps.event.addListener( map, 'dragend', function () { refreshKml(); } );
				google.maps.event.addListener( map, 'zoom_changed', function () { google.maps.event.addListenerOnce( map, "tilesloaded", function () { refreshKml(); } ); } );
				if (full_window) google.maps.event.addDomListener( self, 'resize', function () { refreshKml(); } );
			}
		}
		if (field_enabled || (q["s"] != null && q["s"] == 1)) {
			self.document.getElementById("geocoder-tool").innerHTML = '<a style="display: block; font-size: 1px; text-indent: -200px; overflow: hidden; cursor: pointer; border: none; margin: 0; padding: 0; position: absolute; top: 0; left: 0; width: 15px; height: 15px; z-index: 10000; background-image: url(\'./gmap/search.gif\')" onclick="toggleSearchBox()" title="住所検索">住所検索</a><form id="geocoder-search" action="#" onsubmit="geocoderSearch(); return false;" style="display: none; position: absolute; top: 24px; left: 76px; float: left"><input type="search" placeholder="住所検索" results="5" autosave="geocodersearch" size="24" id="geocoderkey" value="" style="font-size: 13px" /><input type="button" onclick="geocoderSearch()" value="検索" /><img style="border: 0px none ; margin-left: 3px; width: 14px; height: 13px; -moz-user-select: none; cursor: pointer;" src="http://maps.gstatic.com/mapfiles/close.gif" onclick="toggleSearchBox()" title="住所検索欄を閉じる" /></form>';
			self.document.getElementById("geocoder-search").style.display = "none";
			if (field_enabled) {
				google.maps.event.addListener( map, 'dragend', function () { centerMarker(); saveMap(); } );
				google.maps.event.addListener( map, 'zoom_changed', function () { google.maps.event.addListenerOnce( map, "tilesloaded", function () { centerMarker(); saveMap(); } ); } );
				google.maps.event.addListener( map, 'maptypeid_changed', function () {  saveMap(); } );
			}
		}
		if (typeof map_center.distanceFrom != "function") {
			google.maps.LatLng.prototype.distanceFrom = function(newLatLng) {
				var R = 6371000;
				var lat1 = this.lat();
				var lon1 = this.lng();
				var lat2 = newLatLng.lat();
				var lon2 = newLatLng.lng();
				var dLat = (lat2-lat1) * Math.PI / 180;
				var dLon = (lon2-lon1) * Math.PI / 180;
				var a = Math.sin(dLat/2) * Math.sin(dLat/2) + Math.cos(lat1 * Math.PI / 180 ) * Math.cos(lat2 * Math.PI / 180 ) * Math.sin(dLon/2) * Math.sin(dLon/2);
				var c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1-a));
				var d = R * c;
				return d;
			}
		}
	} else {
		if (q["key"] != null && q["key"] != "") {
			if (w > 512) w = 512;
			if (h > 512) h = 512;
			var gmap_img = document.createElement('img');
			gmap_img.style.width = w + "px";
			gmap_img.style.height = h + "px";
			gmap_img.style.border = "none";
			if (q["m"] != null && q["m"] != "") gmap_img.title = q["m"].replace(/<.*?>/,'');
			var center = ((q["c"] != null && q["c"] != "") ? q["c"] : '36.315125,137.504883');
			gmap_img.src	= 'http://maps.google.com/staticmap?key=' + q["key"]
							+ '&center=' + center
							+ '&zoom=' + ((q["z"] != null && q["z"] != "" && !isNaN(q["z"])) ? parseInt(q["z"]) : 4)
							+ '&size=' + w + 'x' + h
							+ ((q["m"] != null && q["m"] != "") ? '&markers=' + center : '');
			self.document.getElementById("map").appendChild(gmap_img);
		}
		var gmap_msg = document.createElement('p');
		gmap_msg.style.position = 'absolute';
		gmap_msg.style.backgroundColor = '#FFF';
		gmap_msg.style.color = '#000';
		gmap_msg.style.top = 0;
		gmap_msg.style.left = 0;
		gmap_msg.innerHTML = 'Google マップを表示できませんでした。';
		self.document.getElementById("map").appendChild(gmap_msg);
	}
}

function changeLinkTarget () {
	var self_links = document.getElementsByTagName('a');
	for (var i=0; i<self_links.length; i++) {
		if (
				typeof self_links[i].getAttribute("href") == "string"
				&& self_links[i].getAttribute("href").search(/^http/i) != -1
				&& self_links[i].getAttribute("href").search(/^http:\/\/\w+\.google/i) == -1
				&& (self_links[i].target == null || self_links[i].target == "")
		) {
			if (q["tr"] != null && q["tr"] == "p") {
				self_links[i].target = "_parent";
			} else if (q["tr"] != null && q["tr"] == "t") {
				self_links[i].target = "_top";
			} else if (q["tr"] != null && q["tr"] == "s") {
				self_links[i].target = "_self";
			} else if (q["tr"] != null && q["tr"] == "d") {
				if (self_links[i].getAttribute("href").search(/m=(DetailViewer|Inquiry)&/) != -1) {
					self_links[i].target = "detailViewer";
					self_links[i].onclick = function () { window.open('','detailViewer','width='+dw+',height='+dh+',scrollbars=yes,resizable=yes'); };
				} else {
					self_links[i].target = "_blank";
				}
			} else {
				self_links[i].target = "_blank";
			}
		}
	}
	var self_forms = document.getElementsByTagName('form');
	for (var i=0; i<self_forms.length; i++) {
		if (
				typeof self_forms[i].getAttribute("action") == "string"
				&& self_forms[i].getAttribute("action").search(/^http/i) != -1
				&& self_forms[i].getAttribute("action").search(/^http:\/\/\w+\.google/i) == -1
				&& (kml_by_myself || self_forms[i].target == null || self_forms[i].target == "")
		) {
			if (q["tr"] != null && q["tr"] == "p") {
				self_forms[i].target = "_parent";
			} else if (q["tr"] != null && q["tr"] == "t") {
				self_forms[i].target = "_top";
			} else if (q["tr"] != null && q["tr"] == "s") {
				self_forms[i].target = "_self";
			} else {
				self_forms[i].target = "_blank";
			}
		}
	}
}

function setStreetViewCanvasSize(w,h) {
	var svw = parseInt(w * 2 / 3);
	var svh = parseInt(h * 3 / 5);
	svw = (svw > 640) ? 640 : (svw > (w - 83) || svw < 232) ? (w - 68) : svw;
	svh = (svh > 615) ? 615 : (svh > (h - 180) || svw < 202) ? (h - 168) : svh;
	streetview_node.style.width = svw + 'px';
	streetview_node.style.height = svh + 'px';
	streetview_canvas.style.width = svw + 'px';
	streetview_canvas.style.height = svh + 'px';
	if (svw < 232 || svh < 202) {
		map.setStreetView(null);
	} else {
		map.setStreetView(streetview_panorama);
	}
}

function makeCenterMarker(make_from_form) {
	if (center_marker != null) center_marker.setMap(null);
	var center_marker_image = null;
	if (make_from_form) {
		var mk;
		var mka;
		var mkv;
		var mks;
		if (mk_field != null && (mkc_field == null || mkc_field.checked)) {
			if (mk_field.type.search(/select/) != -1) {
				mk = mk_field.options[mk_field.options.selectedIndex].value;
			} else if (mk_field.value != null && mk_field.value != "") {
				mk = mk_field.value;
			}
		}
		if (mka_field != null) {
			if (mka_field.type.search(/select/) != -1) {
				mka = mka_field.options[mka_field.options.selectedIndex].value;
			} else if (mk_field.value != null && mk_field.value != "") {
				mka = mka_field.value;
			}
		}
		if (mkv_field != null) {
			if (mkv_field.type.search(/select/) != -1) {
				mkv = mkv_field.options[mkv_field.options.selectedIndex].value;
			} else if (mk_field.value != null && mk_field.value != "") {
				mkv = mkv_field.value;
			}
		}
		if (mk != null && mk != "" && mk.search(/^https?:\/\/.*\.(gif|png|jpg|jpeg)$/i) != -1) {
			minimarker_disabled = true;
			center_marker_image = getCustomMarkerImage(mk,mka,mkv,null);
		} else if (q["mk"] != null && q["mk"] != "") {
			center_marker_image = getCustomMarkerImage(q["mk"],((mkc_field != null) ? mka : q["mka"]),((mkc_field != null) ? mkv : q["mkv"]),q["mks"]);
		} else {
			minimarker_disabled = false;
			center_marker_image = getMarkerImage();
		}
	} else if (q["mk"] != null && q["mk"] != "") {
		center_marker_image = getCustomMarkerImage(q["mk"],q["mka"],q["mkv"],q["mks"]);
	} else {
		center_marker_image =  getMarkerImage();
	}
	center_marker = new google.maps.Marker({
		position	: map_center,
		map			: map,
		icon		: center_marker_image.icon,
		shadow		: center_marker_image.shadow,
		flat		: ((center_marker_image.shadow == null) ? true : false),
		title		: 'この地図の中心'
	});
	google.maps.event.addListener(
		center_marker,
		"click",
		function () {
			map.setOptions({draggable : false});
			map_center = map.getCenter();
			if (m_field.value != "") {
				if (!center_marker.info_window) center_marker.info_window = new google.maps.InfoWindow({
					content: '<div style="font-size: 14px">' + m_field.value + '</div>',
					maxWidth: mw
				});
				center_marker.info_window.open(map,center_marker);
				google.maps.event.addListener(
					center_marker.info_window,
					"closeclick",
					function () {
						map.setOptions({draggable : true});
						map.panTo(map_center);
					}
				);
			}
		}
	);
	google.maps.event.addListener(
		map,
		"drag",
		function () {
			center_marker.setPosition(map.getCenter());
		}
	);
	centerMarker();
}

function getCustomMarkerImage(url,mka,mkv,surl) {
	var g_image = new Image();
	g_image.src = url;
	var w = g_image.width;
	var h = g_image.height;
	if (surl != null && surl != "") {
		var sg_image = new Image();
		sg_image.src = surl;
		var sw = sg_image.width;
		var sh = sg_image.height;
	}
	if (w != null && w > 0) {
		if (mka == null) mka = "center";
		if (mkv == null) mkv = "bottom";
		var a = (mka == "left") ? 0 : (mka == "right") ? w : parseInt(w/2);
		var v = (mkv == "top") ? 0 : (mkv == "center") ? parseInt(h/2) : (h+1);
		minimarker_disabled = true;
		return getMarkerImageFrom(url,w,h,a,v,surl,sw,sh);
	} else {
		return getMarkerImage();
	}
}

function getMarkerImageFrom(url,w,h,a,v,surl,sw,sh) {
	icon = new google.maps.MarkerImage(url,
		new google.maps.Size(w, h),
		new google.maps.Point(0, 0),
		new google.maps.Point(a, v)
	);
	icon.image_url = url;
	if (surl) {
		shadow = new google.maps.MarkerImage(surl,
			new google.maps.Size(((sw != null && sw > 0) ? sw : w*2), ((sh != null && sh > 0) ? sh : h)),
			new google.maps.Point(0, 0),
			new google.maps.Point(a, v)
		);
		shadow.image_url = surl;
	} else {
		shadow = null;
	}
	return {
		icon	:	icon,
		shadow	:	shadow
	};
}

function getCustomMarkerImageFromKml(icon_style) {
	var url = getNodeValue(icon_style.getElementsByTagName("href")[0]);
	var w = parseInt(getNodeValue(icon_style.getElementsByTagName("width")[0]));
	var h = parseInt(getNodeValue(icon_style.getElementsByTagName("height")[0]));
	var a = parseInt(getNodeValue(icon_style.getElementsByTagName("anchorx")[0]));
	var v = parseInt(getNodeValue(icon_style.getElementsByTagName("anchory")[0]));
	var surl = getNodeValue(icon_style.getElementsByTagName("shadow")[0]);
	var sw = parseInt(getNodeValue(icon_style.getElementsByTagName("swidth")[0]));
	var sh = parseInt(getNodeValue(icon_style.getElementsByTagName("sheight")[0]));
	if (url != "" && w > 0) {
		return getMarkerImageFrom(url,w,h,a,v,surl,sw,sh);
	} else {
		return {
			icon	:	null,
			shadow	:	null
		};
	}
}

function refreshKml() {
	if (kml_refreshing) return;
	kml_refreshing = true;
	var kml_refresh_url = kml_url;
	if ((q["r"] != null && q["r"] == 1) || kml_overlay != null || kml_objects != null) {
		if (map.getBounds() != null) {
			kml_refresh_url += ((kml_refresh_url.search(/\?/) == -1) ? '?' : '&') + 'gmap_sw=' + map.getBounds().getSouthWest().lat() + ',' + map.getBounds().getSouthWest().lng() + '&gmap_ne=' + map.getBounds().getNorthEast().lat() + ',' + map.getBounds().getNorthEast().lng();
		} else {
			kml_refreshing = false;
			return;
		}
		if (kml_by_myself && kml_objects != null) {
			for (var i=0; i<kml_objects.length; i++) {
				if (kml_objects[i].info_window) kml_objects[i].info_window.close(); 
				kml_objects[i].setMap(null);
			}
			kml_objects = new Array();
		} else if (!kml_by_myself && kml_overlay != null) {
			kml_overlay.setMap(null);
		}
	}
	if (!kml_by_myself) {
		kml_overlay = new google.maps.KmlLayer(kml_refresh_url,{ map : map, preserveViewport : ((q["fit"] != null && q["fit"] == 1) ? false : true) });
		if (q["tr"] != null && q["tr"] != "") google.maps.event.addListener(kml_overlay,'click',function() { setTimeout(function() { changeLinkTarget(); }, 1000 ); });
		if (q["fit"] != null && q["fit"] == 1) saveMap();
	}
	if (kml_by_myself || (q["d"] != null && q["d"] >= 1)) {
		var request = createXmlHttpRequest();
		request.open("GET", kml_refresh_url, true);
		request.onreadystatechange = function () {
			if (request.readyState == 4) {
				var kml = xmlParse(request.responseText);
				if ((kml_by_myself && q["fit"] != null && q["fit"] == 1) || (q["d"] != null && q["d"] >= 1)) {
					var coordinates = kml.documentElement.getElementsByTagName("coordinates");
					var n;
					var e;
					var s;
					var w;
					for (var i=0; i<coordinates.length; i++) {
						var points = getNodeValue(coordinates[i]).replace(/^\s+/,'').replace(/\s+$/,'').split(/\s+/);
						var len = points.length;
						var center_n = Math.floor(len/2);
						var center_point = null;
						var start_point = null;
						var prev_point = null;
						var distance = 0;
						for (var j=0; j<len; j++) {
							var lnglat = points[j].split(/,/);
							if (lnglat[0] != null && lnglat[1] != null) {
								var lng = parseFloat(lnglat[0]);
								var lat = parseFloat(lnglat[1]);
								if (kml_by_myself && q["fit"] != null && q["fit"] == 1) {
									if (n == null || lat > n) n = lat;
									if (s == null || lat < s) s = lat;
									if (e == null || lng > e) e = lng;
									if (w == null || lng < w) w = lng;
								}
								if (q["d"] != null && q["d"] >= 1) {
									var here = new google.maps.LatLng(lat,lng);
									if (start_point == null) start_point = here;
									if (j == center_n && len > 1) center_point = here;
									if (typeof here.distanceFrom != "function") simDistanceFrom();
									if (prev_point != null) distance += here.distanceFrom(prev_point);
									prev_point = here;
								}
							}
						}
						if (q["d"] != null && q["d"] >= 1 && center_point != null) {
							var distance_info = formattedDistance(distance);
							if (len == 2) {
								center_point = new google.maps.LatLng(parseFloat((center_point.lat() + start_point.lat()) / 2),parseFloat((center_point.lng() + start_point.lng()) / 2));
							} else if (q["d"] == 2) {
								var shortest = prev_point.distanceFrom(start_point);
								if (shortest != distance) distance_info += '<div style="font-size: 12px">(直線距離:' + formattedDistance(shortest) + ')</div>';
							}
							if (measure_icon == null) measure_icon = getMeasureImage();
							makeMarker(center_point,measure_icon,distance_info);
						}
					}
				}
				if (kml_by_myself) {
					if (list != null) {
						if (list_box != null) list_box.style.display = "none";
						while (list.hasChildNodes()) {
							list.removeChild(list.lastChild)
						}
					}
					if (kml_objects == null) kml_objects = new Array();
					if (default_icon == null) {
						if (kml.documentElement.getElementsByTagName("Style")[0] != null) {
							var first_style = kml.documentElement.getElementsByTagName("Style")[0];
							if ((first_style.getAttribute("id") == "defaultIcon" || (nosync && first_style.getAttribute("id") == "temporaryIcon")) && first_style.getElementsByTagName("IconStyle")[0] != null) {
								default_icon = getCustomMarkerImageFromKml(first_style.getElementsByTagName("IconStyle")[0]);
								minimarker_disabled = true;
							}
						}
						if (default_icon == null) default_icon = (q["mk"] != null && q["mk"] != "") ? getCustomMarkerImage(q["mk"],q["mka"],q["mkv"],q["mks"]) : getMarkerImage();
					}
					var i = 0;
					var network_links = kml.documentElement.getElementsByTagName("NetworkLink");
					for (i=0; i<network_links.length; i++) {
						setKmlLayer(getNodeValue(network_links[i].getElementsByTagName("href")[0]));
					}
					var placemarks = kml.documentElement.getElementsByTagName("Placemark");
					var center_placemark = null;
					for (i=0; i<placemarks.length; i++) {
						var placemarker;
						var placemark_icon = null;
						var placemark_name = getNodeValue(placemarks[i].getElementsByTagName("name")[0]);
						var placemark_description = getNodeValue(placemarks[i].getElementsByTagName("description")[0]);
						var placemark_link = (placemarks[i].getElementsByTagName("atom:link")[0] != null) ? placemarks[i].getElementsByTagName("atom:link")[0].getAttribute("href") : (placemarks[i].getElementsByTagName("link")[0] != null) ? placemarks[i].getElementsByTagName("link")[0].getAttribute("href") : null;
						var placemark_id = (placemarks[i].getElementsByTagName("atom:id")[0] != null) ? getNodeValue(placemarks[i].getElementsByTagName("atom:id")[0]) : (placemarks[i].getElementsByTagName("id")[0] != null) ? getNodeValue(placemarks[i].getElementsByTagName("id")[0]) : null;
						var placemark_lnglat = getNodeValue(placemarks[i].getElementsByTagName("coordinates")[0]).split(/,/);
						var placemark_point = (placemark_lnglat.length <= 1) ? map.getCenter() : new google.maps.LatLng(parseFloat(placemark_lnglat[1]),parseFloat(placemark_lnglat[0]));
						if (placemarks[i].getElementsByTagName("IconStyle")[0] != null) placemark_icon = getCustomMarkerImageFromKml(placemarks[i].getElementsByTagName("Style")[0]);
						placemarker = makeMarker(placemark_point,((placemark_icon == null) ? default_icon : placemark_icon),placemark_name,placemark_description);
						if (!nosync && placemark_link != null && placemark_link != "") {
							setMouseOverImage(
								placemark_link,
								placemarker,
								placemark_name,
								placemark_description,
								((placemark_icon == null) ? minimarker_disabled : true)
							);
						}
						kml_objects.push(placemarker);
						if (q["opn"] != null && (q["opn"] == placemark_id || q["opn"] == placemark_link)) {
							center_placemark = {
								"link"				:	placemark_link,
								"marker"			:	placemarker,
								"name"				:	placemark_name,
								"description"		:	placemark_description,
								"is_custom_icon"	:	((placemark_icon == null) ? minimarker_disabled : true)
							};
							q["opn"] = null;
						}
						if (list != null && placemark_link != null) {
							var list_a = _caller.document.createElement("a");
							list_a.href = placemark_link;
							if (q["tr"] != null && q["tr"] == "p") {
								list_a.target = "_self";
							} else if (q["tr"] != null && q["tr"] == "t") {
								list_a.target = "_top";
							} else if (q["tr"] != null && q["tr"] == "s") {
								list_a.target = "_self";
							} else if (q["tr"] != null && q["tr"] == "d") {
								list_a.target = "detailViewer";
								list_a.onclick = function () { window.open('','detailViewer','width='+dw+',height='+dh+',scrollbars=yes,resizable=yes'); };
							} else {
								list_a.target = "_blank";
							}
							setMouseOverImage(
								placemark_link,
								placemarker,
								placemark_name,
								placemark_description,
								((placemark_icon == null) ? minimarker_disabled : true),
								[list_a]
							);
							
							var list_img = _caller.document.createElement('img');
							list_img.src = (placemark_icon) ? placemark_icon.icon.image_url : default_icon.icon.image_url;
							list_a.appendChild(list_img);
							list_a.appendChild(_caller.document.createTextNode(placemark_name));
							var list_li = _caller.document.createElement('li');
							list_li.appendChild(list_a);
							list.appendChild(list_li);
						}
					}
					var screen_overlays = kml.documentElement.getElementsByTagName("ScreenOverlay");
					if (screen_overlays && screen_overlays[0]) {
						var screen_overlay = screen_overlays[0];
						if (screen_overlay.getElementsByTagName("Icon")[0] != null) {
							var screen_overlay_icon = getNodeValue(screen_overlay.getElementsByTagName("Icon")[0].getElementsByTagName("href")[0]);
							var w = ((self.innerWidth) ? self.innerWidth : ((document.compatMode != null && document.compatMode != "BackCompat") ? self.document.documentElement.clientWidth : self.document.body.clientWidth));
							var h = ((self.innerHeight) ? self.innerHeight : ((document.compatMode != null && document.compatMode != "BackCompat") ? self.document.documentElement.clientHeight : self.document.body.clientHeight))
							var screen_overlay_name = getNodeValue(screen_overlay.getElementsByTagName("name")[0]);
							var screen_overlay_description = getNodeValue(screen_overlay.getElementsByTagName("description")[0]);
							if (screen_overlay.getElementsByTagName("size")[0] != null) {
								var thisSize = screen_overlay.getElementsByTagName("size")[0];
								var screen_overlay_width = parseInt(thisSize.getAttribute("width"));
								var screen_overlay_height = parseInt(thisSize.getAttribute("height"));
							} else {
								var screen_overlay_width = parseInt(w/2);
								var screen_overlay_height = parseInt(h/2);
							}
						}
						var overlay_msg = document.createElement('div');
						overlay_msg.style.position = 'absolute';
						overlay_msg.style.top = parseInt((h - screen_overlay_height) / 2) + 'px';
						overlay_msg.style.left = parseInt((w - screen_overlay_width) / 2) + 'px';
						overlay_msg.style.width = screen_overlay_width + 'px';
						overlay_msg.style.height = screen_overlay_height + 'px';
						if (screen_overlay_icon) overlay_msg.style.backgroundImage = 'url("' + screen_overlay_icon + '")';
						self.document.getElementsByTagName("body")[0].appendChild(overlay_msg);
						overlay_msg.setMap = function() { this.parentNode.removeChild(this) };
						kml_objects.push(overlay_msg);
					}
					if (q["fit"] != null && q["fit"] == 1 && n != null && s != null && e != null && w != null) {
						map.fitBounds(new google.maps.LatLngBounds(new google.maps.LatLng(s,w),new google.maps.LatLng(n,e)));
						saveMap();
					}
					if (center_placemark != null) {
						if (!center_placemark.is_custom_icon) toggleMarkerImage(center_placemark.marker,true);
						if ((center_placemark.description != null && center_placemark.description != "") || (center_placemark.title != null && center_placemark.title != "")) {
							if (!center_placemark.marker.info_window) center_placemark.marker.info_window = new google.maps.InfoWindow({
								content		: ((center_placemark.description != null && center_placemark.description != "") ? center_placemark.description : center_placemark.title),
								maxWidth	: mw
							});
							center_placemark.marker.info_window.open(map,center_placemark.marker);
							if (q["tr"] != null && q["tr"] != "") changeLinkTarget();
						}
					}
					if (list != null && list.hasChildNodes() && list_box != null) list_box.style.display = "";
				}
				kml_refreshing = false;
			}
		}
		request.send(null);
	}
}

function setKmlLayer(kml_link) {
	if (kml_link != null) {
		var kml_layer = new google.maps.KmlLayer(kml_link,{ preserveViewport : true });
		kml_layer.setMap(map);
		if (q["tr"] != null && q["tr"] != "") google.maps.event.addListener(kml_layer,'click',function() { setTimeout(function() { changeLinkTarget(); }, 1000 ); });
		kml_objects.push(kml_layer);
	}
}

function setMouseOverImage(placemark_link,placemarker,marker_title,marker_description,is_custom_icon,caller_links) {
	if (!caller_links) caller_links = _caller.document.getElementsByTagName('a');
	for (var i=0; i<caller_links.length; i++) {
		if (caller_links[i].href == placemark_link) {
			google.maps.event.addDomListener(
				caller_links[i],
				'mouseover',
				function () {
					if (!is_custom_icon) toggleMarkerImage(placemarker,true);
					if ((marker_description != null && marker_description != "") || (marker_title != null && marker_title != "")) {
						if (!placemarker.info_window) placemarker.info_window = new google.maps.InfoWindow({
							content		: ((marker_description != null && marker_description != "") ? marker_description : marker_title),
							maxWidth	: mw
						});
						placemarker.info_window.open(map,placemarker);
						if (q["tr"] != null && q["tr"] != "") changeLinkTarget();
					}
				}
			);
			if (!is_custom_icon) {
				google.maps.event.addDomListener(
					caller_links[i],
					'mouseout',
					function () {
						toggleMarkerImage(placemarker,false);
					}
				);
			}
		}
	}
}

function formattedDistance (meter) {
	return (meter > 1000) ? (parseInt(meter) / 1000) + 'km' : parseInt(meter) + 'm';
}

function openCenterInfoWindow() {
	if (m_field.value != "") {
		if (!center_marker.info_window) center_marker.info_window = new google.maps.InfoWindow({
			content		: '<div style="font-size: 14px">' + m_field.value + '</div>',
			maxWidth	: mw
		});
		center_marker.info_window.open(map,center_marker);
		if (q["tr"] != null && q["tr"] != "") changeLinkTarget();
	}
}

function makeMarker(point,marker_image,marker_title,marker_description){
	var marker = new google.maps.Marker({
		position	: point,
		map			: map,
		icon		: marker_image.icon,
		shadow		: marker_image.shadow,
		flat		: ((marker_image.shadow == null) ? true : false),
		title		: marker_title.replace(/<.*?>/g,'')
	});
	google.maps.event.addListener(
		marker,
		"click",
		function () {
			if (!marker.info_window) marker.info_window = new google.maps.InfoWindow({
				content		: ((marker_description != null && marker_description != "") ? marker_description : marker_title),
				maxWidth	: mw
			});
			marker.info_window.open(map,marker);
			if (q["tr"] != null && q["tr"] != "") changeLinkTarget();
		}
	);
	return marker;
}

function geocoderSearch() {
	var keyword = self.document.getElementById('geocoderkey').value;
	if (keyword != null && keyword != "") {
		if (geocoder_client == null) geocoder_client = new google.maps.Geocoder();
		geocoder_client.geocode(
			{ address : keyword },
			function (results, status) {
				if (status == google.maps.GeocoderStatus.OK) {
					var z = map.getZoom();
					map.setCenter(results[0].geometry.location);
					map.setZoom((z < 10) ? 15 : z);
					saveMap();
					centerMarker();
				} else {
					alert("条件に該当する地図は見つかりませんでした");
				}
			}
		);
	}
}

function toggleSearchBox() {
	var search_box = self.document.getElementById("geocoder-search");
	if (search_box.style.display == null || search_box.style.display == 'none') {
		var addr = '';
		if (addr_field_ids != null && addr_field_ids.constructor == Array && addr_field_ids.length > 0) {
			for (var i in addr_field_ids) {
				if (_caller.document.getElementById(addr_field_ids[i])) {
					var addr_field = _caller.document.getElementById(addr_field_ids[i])
					if (addr_field.type != null && addr_field.type == 'select') {
						addr += addr_field.options[addr_field.options.selectedIndex].value;
					} else {
						addr += addr_field.value;
					}
				}
			}
			if (addr != "") self.document.getElementById("geocoderkey").value = addr;
		}
		search_box.style.display = 'block';
		self.document.getElementById("geocoderkey").focus();
		if (addr == "") self.document.getElementById("geocoderkey").select();
	} else {
		search_box.style.display = 'none';
	}
}

function saveMap() {
	if (z_field != null) z_field.value = map.getZoom();
	if (t_field != null) {
		var map_type = map.getMapTypeId();
		t_field.value = (map_type == google.maps.MapTypeId.SATELLITE) ? 'k' : (map_type == google.maps.MapTypeId.HYBRID) ? 'h' : (map_type == google.maps.MapTypeId.TERRAIN) ? 'p' : '';
	}
	if (c_field != null) c_field.value = map.getCenter().lat() + ',' + map.getCenter().lng();
	if (fit_field != null) fit_field.checked = false;
}

function centerMarker() {
	if (center_marker != null) center_marker.setPosition(map.getCenter());
}

function urlDecode(query) {
	var hash = new Array();
	if (query == null || query == "" || query.search("=") == -1) return hash;
	query = query.replace(/^\?/,'').split('&');
	for (var i=0; i<query.length; i++) {
		var p = query[i].split('=');
		if (window.decodeURIComponent) {
			p[0] = decodeURIComponent(p[0].replace(/\+/g,' '));
			p[1] = decodeURIComponent(p[1].replace(/\+/g,' '));
		} else {
			p[0] = unescape(p[0].replace(/\+/g,' '));
			p[1] = unescape(p[1].replace(/\+/g,' '));
		}
		if (hash[p[0]] == null) {
			hash[p[0]] = p[1];
		} else {
			if (hash[p[0]].constructor == Array) {
				hash[p[0]].push(p[1]);
			} else {
				hash[p[0]] = new Array(hash[p[0]],p[1]);
			}
		}
	}
	return hash;
}

function urlEncode (hash) {
	var query = '';
	for (var key in hash) {
		if (hash[key] != null) {
			var encoded_key = ((window.encodeURIComponent) ? encodeURIComponent(key) : escape(key)).replace(/ /g,'+')
			if (hash[key].constructor == Array) {
				for (var i=0; i<hash[key].length; i++) {
					if ((typeof hash[key][i] == "string" || typeof hash[key][i] == "number") && hash[key][i] != null) query += ((query != "") ? "&" : "") + encoded_key + "=" + ((window.encodeURIComponent) ? encodeURIComponent(hash[key][i]) : escape(hash[key][i])).replace(/ /g,'+');
				}
			} else if (typeof hash[key] == "string" || typeof hash[key] == "number") {
				query += ((query != "") ? "&" : "") + encoded_key + "=" + ((window.encodeURIComponent) ? encodeURIComponent(hash[key]) : escape(hash[key])).replace(/ /g,'+');
			}
		}		
	}
	return query;
}

function getHashFromForm (this_form) {
	var hash = new Array();
	for (var i=0; i < this_form.elements.length; i++) {
		if (typeof this_form.elements[i].name != "undefined" && this_form.elements[i].name != "" && (typeof this_form.elements[i].value == "string" || typeof this_form.elements[i].value == "number")) {
			var name = this_form.elements[i].name;
			if (this_form.elements[i].type == null || typeof this_form.elements[i].type == "undefined") {
				hash[name] = _setHashValue(hash[name],this_form.elements[i].value);
			} else if (this_form.elements[i].type == 'text' || this_form.elements[i].type == 'password' || this_form.elements[i].type == 'textarea' || this_form.elements[i].type == 'hidden' || this_form.elements[i].type == 'submit' || this_form.elements[i].type == 'image' || this_form.elements[i].type == 'search') {
				if (this_form.elements[i].type == 'hidden' && this_form.elements[i].getAttribute('alt') && typeof this_form.elements[i].getAttribute('alt') == 'string') {
					hash[name] = _setHashValue(hash[name],this_form.elements[i].getAttribute('alt'));
				} else {
					hash[name] = _setHashValue(hash[name],this_form.elements[i].value);
				}
			} else if (this_form.elements[i].type == 'checkbox' || this_form.elements[i].type == 'radio') {
				if (this_form.elements[i].checked) hash[name] = _setHashValue(hash[name],this_form.elements[i].value);
			} else if (this_form.elements[i].type.search(/select/) != -1) {
				for (var o=0; o < this_form.elements[i].options.length; o++) {
					if (this_form.elements[i].options[o].selected) hash[name] = _setHashValue(hash[name],this_form.elements[i].options[o].value);
				}
			}
		}
	}
	return hash;
}

function _setHashValue (p,v) {
	if (p != null) {
		if (p.constructor == Array) {
			p.push(v);
		} else {
			p = new Array(p,v);
		}
	} else {
		p = v;
	}
	return p;
}

function createXmlHttpRequest() {
	try {
		if (typeof ActiveXObject != 'undefined') {
			return new ActiveXObject('Microsoft.XMLHTTP');
		} else if (window["XMLHttpRequest"]) {
			return new XMLHttpRequest();
		}
	} catch (e) {
		changeStatus(e);
	}
	return null;
};

function xmlParse(str) {
	if (typeof ActiveXObject != 'undefined' && typeof GetObject != 'undefined') {
		var doc = new ActiveXObject('Microsoft.XMLDOM');
		doc.loadXML(str);
		return doc;
	}

	if (typeof DOMParser != 'undefined') {
		return (new DOMParser()).parseFromString(str, 'text/xml');
	}

	return createElement('div', null);
}

function getNodeValue(node){
	if (!node) {
		return"";
	}
	var retStr="";
	if (node.nodeType==3 || node.nodeType==4 || node.nodeType==2) {
		retStr += node.nodeValue;
	} else if(node.nodeType==1 || node.nodeType==9 || node.nodeType==11) {
		for (var i=0; i<node.childNodes.length; ++i) {
			retStr += arguments.callee(node.childNodes[i]);
		}
	}
	return retStr;
}
